==> opennms_21.0.3-1.tar.gz: opennms-source/core/ipc/rpc/camel/src/test/java/org/opennms/core/rpc/camel/MockMinionIdentity.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.core.rpc.camel;

import org.opennms.minion.core.api.MinionIdentity;

public class MockMinionIdentity implements MinionIdentity {

    private final String location;

    public MockMinionIdentity(String location) {
        this.location = location;
    }

    @Override
    public String getId() {
        return "0";
    }

    @Override
    public String getLocation() {
        return location;
    }
}

==> opennms_23.0.2-1.tar.gz: opennms-source/core/ipc/rpc/camel/src/test/java/org/opennms/core/rpc/camel/MockMinionIdentity.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.core.rpc.camel;

import org.opennms.distributed.core.api.MinionIdentity;
import org.opennms.distributed.core.api.SystemType;

public class MockMinionIdentity implements MinionIdentity {

    private final String location;

    public MockMinionIdentity(String location) {
        this.location = location;
    }

    @Override
    public String getId() {
        return "0";
    }

    @Override
    public String getLocation() {
        return location;
    }

    @Override
    public String getType() {
        return SystemType.Minion.name();
    }
}
